==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/compton-conf/compton-conf_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Specialių efektų nustatymai</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Šešėlis</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="30"/>
        <source>The blur radius for shadows</source>
        <translation>Šešėlių suliejimo spindulys</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="40"/>
        <source>The left offset for shadows</source>
        <translation>Kairysis šešėlių poslinkis</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="54"/>
        <source>The top offset for shadows</source>
        <translation>Viršutinis šešėlių poslinkis</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="68"/>
        <source>The translucency for shadows</source>
        <translation>Dalinis šešėlių permatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="75"/>
        <source>Color of shadow</source>
        <translation>Šešėlio spalva</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="89"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Pataisyti tam tikrus keistumus su ARGB langais</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="92"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Nustatyti ties nuliu dalį už lango esančios šešėlio kaukės</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="99"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Nebraižyti šešėlių ant DND langų</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="106"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Vengti braižyti šešėlius ant dėklo/skydelio langų</translation>
    </message>
    <message>
        <source>Enabled client-side shadows on windows</source>
        <translation type="vanished">Įjungti kliento pusės šešėlius ant langų</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="113"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Įjungti kliento pusės šešėlius ant langų</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="120"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Vengti braižyti šešėlius ant visų langų, kurie naudoja
X Shape plėtinį</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="138"/>
        <source>Opacity</source>
        <translation>Nepermatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="147"/>
        <source>The opacity for menus</source>
        <translation>Meniu nepermatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="154"/>
        <source>Default opacity of inactive windows</source>
        <translation>Numatytasis neaktyvių langų nepermatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="161"/>
        <source>Default opacity for active windows</source>
        <translation>Numatytasis aktyvių langų nepermatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="168"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Lango pavadinimo juostos ir rėmelio nepermatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="175"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRender vidinė pusė: Žingsnio dydis permatomiems paveikslams
(Jo padidinimas gali privesti prie mažesnio X serverio išteklių naudojimo)</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="183"/>
        <source>Dim inactive windows</source>
        <translation>Užtemdyti neaktyvius langus</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="190"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Neleisti reguliuoti užtemdymą pagal lango nepermatomumą</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="197"/>
        <source>Blur background of transparent windows</source>
        <translation>Sulieti permatomų langų foną</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="204"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Sulieti nepermatomų langų su permatomu rėmeliu foną</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="211"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Neleisti reguliuoti suliejimo spindulį pagal lango nepermatomumą</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="279"/>
        <source>Fade</source>
        <translation>Išblukimas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="285"/>
        <source>Fade windows during opacity changes</source>
        <translation>Išblukinti langus nepermatomumo keitimo metu</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="292"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Laikas tarp išblukimo žingsnių, milisekundėmis</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="299"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Nepermatomumo pokytis tarp žingsnių,
langui palaipsniui atsirandant</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="306"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Nepermatomumo pokytis tarp žingsnių,
langui palaipsniui išnykstant</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="313"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Vengti palaipsnio langų atsiradimo/išnykimo,
juos atveriant/užveriant</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="356"/>
        <source>Other</source>
        <translation>Kita</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="368"/>
        <source>Rendering backend</source>
        <translation>Atvaizdavimo vidinė pusė</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="380"/>
        <source>X Render</source>
        <translation>X Render</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="387"/>
        <source>GLX (OpenGL)</source>
        <translation>GLX (OpenGL)</translation>
    </message>
    <message>
        <source>Not implemented yet</source>
        <translation type="vanished">Kol kas neįgyvendinta</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="403"/>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="206"/>
        <source>About ComptonConf</source>
        <translation>Apie ComptonConf</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="207"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - konfigūravimo įrankis, skirtas compton

Autorių teisės (C) 2013
Autorius: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/compton-conf/compton-conf_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Specialių efektų nustatymai</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Šešėlis</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>Šešėlių suliejimo spindulys</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Kairysis šešėlių poslinkis</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Viršutinis šešėlių poslinkis</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>Dalinis šešėlių permatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Šešėlio spalva</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Pataisyti tam tikrus keistumus su ARGB langais</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Nustatyti ties nuliu dalį už lango esančios šešėlio kaukės</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Nebraižyti šešėlių ant DND langų</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Vengti braižyti šešėlius ant dėklo/skydelio langų</translation>
    </message>
    <message>
        <source>Enabled client-side shadows on windows</source>
        <translation type="vanished">Įjungti kliento pusės šešėlius ant langų</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Įjungti kliento pusės šešėlius ant langų</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Vengti braižyti šešėlius ant visų langų, kurie naudoja
X Shape plėtinį</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation>Apkirpti išskleistų langų šešėlius iš išplėstų ekranų</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Nepermatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>Meniu nepermatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Numatytasis neaktyvių langų nepermatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Numatytasis aktyvių langų nepermatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Lango pavadinimo juostos ir rėmelio nepermatomumas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRender vidinė pusė: Žingsnio dydis permatomiems paveikslams
(Jo padidinimas gali privesti prie mažesnio X serverio išteklių naudojimo)</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Užtemdyti neaktyvius langus</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Neleisti reguliuoti užtemdymą pagal lango nepermatomumą</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Sulieti permatomų langų foną</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Sulieti nepermatomų langų su permatomu rėmeliu foną</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Neleisti reguliuoti suliejimo spindulį pagal lango nepermatomumą</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Išblukimas</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Išblukinti langus nepermatomumo keitimo metu</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Laikas tarp išblukimo žingsnių, milisekundėmis</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Nepermatomumo pokytis tarp žingsnių,
langui palaipsniui atsirandant</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Nepermatomumo pokytis tarp žingsnių,
langui palaipsniui išnykstant</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Vengti palaipsnio langų atsiradimo/išnykimo,
juos atveriant/užveriant</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Kita</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation>Atvaizdavimo vidinė pusė</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation>X Render</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation>GLX (OpenGL)</translation>
    </message>
    <message>
        <source>Not implemented yet</source>
        <translation type="vanished">Kol kas neįgyvendinta</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>Apie ComptonConf</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - konfigūravimo įrankis, skirtas compton

Autorių teisės (C) 2013
Autorius: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>
